pecos.error\_models.noise\_impl\_old.meas\_noise
================================================

.. automodule:: pecos.error_models.noise_impl_old.meas_noise







   .. rubric:: Functions

   .. autosummary::

      noise_meas_bitflip
